# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.1.0] - 2021-07-23
* First release on PyPI.


## [0.2.2] - 2021-07-29
### Added
- Link to mobile and desktop app stores.

### Fixed
- Broken app store links in app listing


## [0.2.3] - 2021-07-29

### Changed
- Don't assume url pattern


## [0.2.4] - 2021-07-29

### Added
- Capture query params in visit


## [0.2.5] - 2021-07-29

### Changed
- Removed print statement
- Moved `get_querystring_as_dict` into `helpers`

## [0.2.6] - 2021-08-04

### Fixed
- Added missing migrations.
